@@ -2,7 +2,7 @@ from django.http import HttpResponseBadRequest, HttpResponse
 from django.conf import settings
 from django.test.client import CONTENT_TYPE_RE
 
-from achilles.common import achilles_renders
+from achilles.common import AchillesTransport, achilles_renders
 from achilles.actions import run_actions
 
 import json
@@ -18,11 +18,12 @@ def endpoint(request):
     else:
         charset = settings.DEFAULT_CHARSET
 
+    transport = AchillesTransport(request)
     data = json.loads(request.body.decode(charset))
-    run_actions(request, data)
+    run_actions(transport, data)
 
     result = {}
     for (namespace, render) in achilles_renders().items():
-        result[namespace] = render(request)
+        result[namespace] = render(transport)
 
     return HttpResponse(json.dumps(result), content_type="application/json")
